@@ -1,10 +1,9 @@
-#!/usr/bin/python
-from config import Config
-from signature import Signature
-from pingback import Pingback
-from paymentform import PaymentForm
-from refund import Refund
-from subscription import Subscription
+from fasterpay.config import Config
+from fasterpay.signature import Signature
+from fasterpay.pingback import Pingback
+from fasterpay.paymentform import PaymentForm
+from fasterpay.refund import Refund
+from fasterpay.subscription import Subscription
 
 
 class Gateway:
