@@ -1,6 +1,5 @@
-#!/usr/bin/python
-
 import requests
+import json
 
 
 class Subscription:
@@ -10,7 +9,6 @@ class Subscription:
 
     def cancel(self, order_id=None):
         response = requests.post(self.gateway.config.get_api_url() + "/api/subscription/" + str(order_id) + "/cancel",
-                                 data={},
+                                 data=json.dumps({}),
                                  headers={"X-ApiKey": self.gateway.config.get_private_key()})
-
-        return response.json()
+        return response
